#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive-extras
version:              0.10.2.2
visibility:           public
id:                   primitive-extras-0.10.2.2-HcnToNRzSnm4tbl5VoY7aK
key:                  primitive-extras-0.10.2.2-HcnToNRzSnm4tbl5VoY7aK
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/primitive-extras
synopsis:             Extras for the "primitive" library
description:
    Raw collection of extra utiltilies for the "primitive" library.

category:             Primitive
abi:                  892df245766392682a5b5b80cb2449d3
exposed:              True
exposed-modules:
    PrimitiveExtras.Bitmap PrimitiveExtras.By6Bits
    PrimitiveExtras.PrimArray PrimitiveExtras.PrimMultiArray
    PrimitiveExtras.SmallArray PrimitiveExtras.UnliftedArray

hidden-modules:
    PrimitiveExtras.FoldMs PrimitiveExtras.Folds
    PrimitiveExtras.Prelude PrimitiveExtras.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/primitive-extras-0.10.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/primitive-extras-0.10.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/primitive-extras-0.10.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-extras
hs-libraries:         HSprimitive-extras-0.10.2.2-HcnToNRzSnm4tbl5VoY7aK
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    deferred-folds-0.9.18.10-KqaizkZHawMBsRTKVpsye4
    focus-1.0.3.2-BrC9f0LMmAI93WlpildEcz
    foldl-1.4.18-FecSd55hxszJ57GvZJtghx
    list-t-1.0.5.7-EesKDH9OknXGO20tXpsxSf
    primitive-0.9.1.0-G6koubL8eviAMsrrurXf06
    primitive-unlifted-2.2.0.0-EjVU6Ly2uAI72DXnzRoki5
    profunctors-5.6.3-EcD9vqp4m2WJ3pGg9ot77Y
    vector-0.13.2.0-8P1yhfNTE0VJ5EIM0TMJkk

haddock-interfaces:
    /usr/share/doc/haskell-primitive-extras/html/primitive-extras.haddock

haddock-html:         /usr/share/doc/haskell-primitive-extras/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

